@@ -76,3 +76,11 @@ class MultipleTrialResult(BaseResult):
 
 class ItlwResult(MultipleTrialResult):
     pass
+
+
+class VQEResult(BaseResult):
+    expectations: list[float] = Field(default_factory=list)
+    nfevs: list[int] = Field(default_factory=list)
+    initial_params: list[list[float]] = Field(default_factory=list)
+    opt_params: list[list[float]] = Field(default_factory=list)
+    alphas: list[float] = Field(default_factory=list)
\ No newline at end of file
